@@ -1,5 +1,8 @@
 import random
 
+def print(text):
+    return text
+
 chars = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456!£$%^&*(`)"
 
 def gen_password(password_len, password_count):
